@@ -145,13 +145,15 @@ def convert_to_num(version_str):
     100
 
     >>> convert_to_num('1.0.0-alpha')
-    0
+    100
     """
     if not version_str:
         return 0
     if str(version_str).isdigit():
         return version_str
     version_str = version_str.replace(".", "")
+    if "-" in version_str:
+        version_str = version_str.split("-")[0]
     return int(version_str) if version_str.isdigit() else 0
 
 
@@ -164,10 +166,15 @@ def normalise_num(version_num, normal_len):
     >>> normalise_num("1.0.0", 3)
     100
 
+    >>> normalise_num("1.0.0-alpha", 3)
+    100
+
     >>> normalise_num(100, 4)
     1000
     """
     version_num = str(version_num).replace(".", "")
+    if "-" in version_num:
+        version_num = version_num.split("-")[0]
     if len(version_num) < normal_len:
         for i in range(len(version_num), normal_len):
             version_num = version_num + "0"
@@ -202,6 +209,23 @@ def version_compare(compare_ver, min_version, max_version):
     >>> utils.version_compare("4.0.0", "2.0.0", "*")
     True
     """
+    compare_ver_build = None
+    min_version_build = None
+    max_version_build = None
+    # Extract any build string such as alpha or beta
+    if "-" in compare_ver and compare_ver != "-":
+        tmpA = compare_ver.split("-")
+        compare_ver = tmpA[0]
+        compare_ver_build = tmpA[1]
+    if "-" in min_version and min_version != "-":
+        tmpA = min_version.split("-")
+        min_version = tmpA[0]
+        min_version_build = tmpA[1]
+    if "-" in max_version and max_version != "-":
+        tmpA = max_version.split("-")
+        max_version = tmpA[0]
+        max_version_build = tmpA[1]
+
     if max_version == "*":
         return True
     if max_version == "-" or not max_version:
@@ -210,8 +234,10 @@ def version_compare(compare_ver, min_version, max_version):
         min_version = "0"
     if compare_ver == "-" or compare_ver == "*":
         compare_ver = "0"
-    if compare_ver == min_version or compare_ver == max_version:
-        return True
+    # Simple case
+    if not compare_ver_build and not min_version_build and not max_version_build:
+        if compare_ver == min_version or compare_ver == max_version:
+            return True
     compare_ver_parts = str(compare_ver).split(".")
     min_version_parts = str(min_version).split(".")
     max_version_parts = str(max_version).split(".")
@@ -224,6 +250,21 @@ def version_compare(compare_ver, min_version, max_version):
         min_version_num = normalise_num(min_version, len(compare_ver_parts))
         max_version_num = normalise_num(max_version, len(compare_ver_parts))
         if compare_ver_num >= min_version_num and compare_ver_num <= max_version_num:
+            if (
+                compare_ver_build == min_version_build
+                or compare_ver_build == max_version_build
+            ):
+                return True
+            if not compare_ver_build and (min_version_build or max_version_build):
+                if (
+                    compare_ver_num == min_version_num
+                    and compare_ver_num == max_version_num
+                ):
+                    return False
+                if max_version_build and compare_ver_num == max_version_num:
+                    return False
+                else:
+                    return True
             return True
 
     normal_len = len(compare_ver_parts)
